A simple DFA library to construct state machines, fast allocation using an a custom Arena implementation, and safe construction using Rust’s borrow checker.
Modules
- dfa
- The DFA module contains the implementation of the Deterministic Finite Automaton.
- nfa
- The NFA module contains the implementation of the Non-Deterministic Finite Automaton.
Macros
- dfa_
state_ creator - A macro for which allows you to make a state creator function for a given state type.
- nfa_
state_ creator - Creates a macro for creating states in the NFA.